@@ -39,7 +39,7 @@ class Zone:
         self.to_file(sys.stdout)
 
     def to_file(self, f):
-        if type(f) is 'file':
+        if type(f) == 'file':
             fd = f
         elif type(f) is str:
             if os.path.isdir(f):
@@ -203,5 +203,6 @@ def main():
     except IOError as e:
         LOG.error(e)
 
+
 if __name__ == '__main__':
     sys.exit(main())
