@@ -30,15 +30,13 @@ import dns.rcode
 import dns.message
 import dns.flags
 import dns.opcode
+import six
 from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate import utils
 from designate import dnsutils
 from designate.backend import agent_backend
-from designate.i18n import _LW
-from designate.i18n import _LE
-from designate.i18n import _LI
 import designate.backend.private_codes as pcodes
 
 LOG = logging.getLogger(__name__)
@@ -53,8 +51,7 @@ class RequestHandler(object):
             master = {'host': raw_server[0], 'port': int(raw_server[1])}
             self.masters.append(master)
 
-        LOG.info(_LI("Agent masters: %(masters)s"),
-                 {'masters': self.masters})
+        LOG.info("Agent masters: %(masters)s", {'masters': self.masters})
 
         self.allow_notify = CONF['service:agent'].allow_notify
         self.transfer_source = CONF['service:agent'].transfer_source
@@ -89,7 +86,7 @@ class RequestHandler(object):
 
         # TODO(Tim): Answer Type 65XXX queries
         yield response
-        raise StopIteration
+        return
 
     def _handle_query_error(self, request, rcode):
         """
@@ -108,7 +105,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "CREATE", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
@@ -120,7 +119,7 @@ class RequestHandler(object):
             # Does this warrant a warning?
             # There is a race condition between checking if the zone exists
             # and creating it.
-            LOG.warning(_LW("Not creating %(name)s, zone already exists"),
+            LOG.warning("Not creating %(name)s, zone already exists",
                         {'name': zone_name})
             # Provide an authoritative answer
             response.flags |= dns.flags.AA
@@ -137,7 +136,7 @@ class RequestHandler(object):
         except Exception as e:
             # TODO(Federico) unknown exceptions should be logged with a full
             # traceback. Same in the other methods.
-            LOG.error(_LE("Exception while creating zone %r"), e)
+            LOG.error("Exception while creating zone %r", e)
             response.set_rcode(dns.rcode.from_text("SERVFAIL"))
             return response
 
@@ -159,7 +158,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "NOTIFY", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
@@ -168,8 +169,8 @@ class RequestHandler(object):
         serial = self.backend.find_zone_serial(zone_name)
 
         if serial is None:
-            LOG.warning(_LW("Refusing NOTIFY for %(name)s, doesn't exist") %
-                 {'name': zone_name})
+            LOG.warning("Refusing NOTIFY for %(name)s, doesn't exist",
+                        {'name': zone_name})
             response.set_rcode(dns.rcode.from_text("REFUSED"))
             return response
 
@@ -210,7 +211,9 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text().decode('utf-8')
+        zone_name = question.name.to_text()
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if not self._allowed(request, requester, "DELETE", zone_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
@@ -219,8 +222,8 @@ class RequestHandler(object):
         serial = self.backend.find_zone_serial(zone_name)
 
         if serial is None:
-            LOG.warning(_LW("Not deleting %(name)s, zone doesn't exist") %
-                 {'name': zone_name})
+            LOG.warning("Not deleting %(name)s, zone doesn't exist",
+                        {'name': zone_name})
             # Provide an authoritative answer
             response.flags |= dns.flags.AA
             return response
@@ -246,8 +249,8 @@ class RequestHandler(object):
             return True
 
         if requester not in self.allow_notify:
-            LOG.warning(_LW("%(verb)s for %(name)s from %(server)s refused") %
-                     {'verb': op, 'name': zone_name, 'server': requester})
+            LOG.warning("%(verb)s for %(name)s from %(server)s refused",
+                        {'verb': op, 'name': zone_name, 'server': requester})
             return False
 
         return True
