@@ -15,20 +15,23 @@
 # under the License.
 import pecan
 from oslo_config import cfg
+from oslo_log import log as logging
 
 from designate import exceptions
 from designate import utils
 from designate.api.v2.controllers import rest
-from designate.api.v2.controllers import recordsets
+from designate.api.v2.controllers.zones import recordsets
 from designate.api.v2.controllers.zones import tasks
 from designate.api.v2.controllers.zones import nameservers
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
 
-
 CONF = cfg.CONF
 
 
+LOG = logging.getLogger(__name__)
+
+
 class ZonesController(rest.RestController):
 
     SORT_KEYS = ['created_at', 'id', 'updated_at', 'name', 'tenant_id',
@@ -47,9 +50,13 @@ class ZonesController(rest.RestController):
         request = pecan.request
         context = request.environ['context']
 
+        zone = self.central_api.get_zone(context, zone_id)
+
+        LOG.info("Retrieved %(zone)s", {'zone': zone})
+
         return DesignateAdapter.render(
             'API_v2',
-            self.central_api.get_zone(context, zone_id),
+            zone,
             request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
@@ -59,7 +66,7 @@ class ZonesController(rest.RestController):
         context = request.environ['context']
 
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-            params, self.SORT_KEYS)
+                context, params, self.SORT_KEYS)
 
         # Extract any filter params.
         accepted_filters = ('name', 'type', 'email', 'status',
@@ -68,11 +75,12 @@ class ZonesController(rest.RestController):
         criterion = self._apply_filter_params(
             params, accepted_filters, {})
 
-        return DesignateAdapter.render(
-            'API_v2',
-            self.central_api.find_zones(
-                context, criterion, marker, limit, sort_key, sort_dir),
-            request=request)
+        zones = self.central_api.find_zones(
+            context, criterion, marker, limit, sort_key, sort_dir)
+
+        LOG.info("Retrieved %(zones)s", {'zones': zones})
+
+        return DesignateAdapter.render('API_v2', zones, request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
@@ -97,6 +105,8 @@ class ZonesController(rest.RestController):
         # Create the zone
         zone = self.central_api.create_zone(context, zone)
 
+        LOG.info("Created %(zone)s", {'zone': zone})
+
         # Prepare the response headers
         # If the zone has been created asynchronously
 
@@ -145,7 +155,7 @@ class ZonesController(rest.RestController):
             # 1) "Nested" resources? records inside a recordset.
             # 2) What to do when a zone doesn't exist in the first place?
             # 3) ...?
-            raise NotImplemented('json-patch not implemented')
+            raise NotImplementedError('json-patch not implemented')
         else:
             # Update the zone object with the new values
             zone = DesignateAdapter.parse('API_v2', body, zone)
@@ -166,6 +176,8 @@ class ZonesController(rest.RestController):
             zone = self.central_api.update_zone(
                 context, zone, increment_serial=increment_serial)
 
+        LOG.info("Updated %(zone)s", {'zone': zone})
+
         if zone.status == 'PENDING':
             response.status_int = 202
         else:
@@ -184,4 +196,6 @@ class ZonesController(rest.RestController):
         zone = self.central_api.delete_zone(context, zone_id)
         response.status_int = 202
 
+        LOG.info("Deleted %(zone)s", {'zone': zone})
+
         return DesignateAdapter.render('API_v2', zone, request=request)
