@@ -24,7 +24,7 @@ knotc utility.
 
 Supported Knot versions: >= 2.1, < 3
 
-`Knot DNS 2 User documentation <backends/knot2_agent.html>`_
+`Knot DNS 2 User documentation <../../admin/backends/knot2_agent.html>`_
 
 .. WARNING::
 
@@ -48,9 +48,8 @@ from designate import exceptions
 from designate.backend.agent_backend import base
 from designate.utils import execute
 
-
+CFG_GROUP_NAME = 'backend:agent:knot2'
 LOG = logging.getLogger(__name__)
-CFG_GROUP = 'backend:agent:knot2'
 # rootwrap requires a command name instead of full path
 KNOTC_DEFAULT_PATH = 'knotc'
 
@@ -58,45 +57,17 @@ KNOTC_DEFAULT_PATH = 'knotc'
 # perfors AXFR from MiniDNS to the Agent to populate the `zone` argument
 # (needed by the Bind backend)
 
-"""GROUP = backend:agent:knot2"""
-knot2_group = cfg.OptGroup(
-            name='backend:agent:knot2', title="Configuration for Knot2 backend"
-        )
-knot2_opts = [
-    cfg.StrOpt('knotc-cmd-name',
-               help='knotc executable path or rootwrap command name',
-               default='knotc'),
-    cfg.StrOpt('query-destination', default='127.0.0.1',
-               help='Host to query when finding zones')
-]
-
-"""GROUP = backend:agent:msdns"""
-msdns_group = cfg.OptGroup(
-    name='backend:agent:msdns',
-    title="Configuration for Microsoft DNS Server"
-)
-msdns_opts = [
-
-]
-
-cfg.CONF.register_group(knot2_group)
-cfg.CONF.register_opts(knot2_opts, group=knot2_group)
-
 
 class Knot2Backend(base.AgentBackend):
     __plugin_name__ = 'knot2'
     __backend_status__ = 'untested'
     _lock_name = 'knot2.lock'
 
-    @classmethod
-    def get_cfg_opts(cls):
-        return [(knot2_group, knot2_opts)]
-
     def __init__(self, *a, **kw):
         """Configure the backend"""
         super(Knot2Backend, self).__init__(*a, **kw)
 
-        self._knotc_cmd_name = cfg.CONF[CFG_GROUP].knotc_cmd_name
+        self._knotc_cmd_name = cfg.CONF[CFG_GROUP_NAME].knotc_cmd_name
 
     def start(self):
         """Start the backend"""
@@ -189,7 +160,7 @@ class Knot2Backend(base.AgentBackend):
         try:
             serial = out.split('|')[1].split()[1]
             return int(serial)
-        except Exception as e:
+        except Exception:
             LOG.error("Unable to parse knotc output: %r", out)
             raise exceptions.Backend("Unexpected knotc zone-status output")
 
