@@ -26,19 +26,6 @@ from designate.backend.agent_backend import base
 from designate import exceptions
 
 LOG = logging.getLogger(__name__)
-CFG_GROUP = 'backend:agent:msdns'
-
-"""GROUP = backend:agent:msdns"""
-msdns_group = cfg.OptGroup(
-    name='backend:agent:msdns',
-    title="Configuration for Microsoft DNS Server"
-)
-msdns_opts = [
-
-]
-
-cfg.CONF.register_group(msdns_group)
-cfg.CONF.register_opts(msdns_opts, group=msdns_group)
 
 
 class MSDNSBackend(base.AgentBackend):
@@ -60,10 +47,6 @@ class MSDNSBackend(base.AgentBackend):
 
         LOG.info("AXFR masters: %r", self._masters)
 
-    @classmethod
-    def get_cfg_opts(cls):
-        return [(msdns_group, msdns_opts)]
-
     def start(self):
         """Start the backend"""
         LOG.info("Started msdns backend")
