@@ -13,8 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import os
-
 from oslo_log import log as logging
 from oslo_config import cfg
 from oslo_utils import importutils
@@ -39,12 +37,6 @@ except ImportError:
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
-WSDL = os.path.join(os.path.dirname(__file__),
-                    '..',
-                    'resources',
-                    'wsdl',
-                    'EnhancedDNS.xml')
-
 
 class EnhancedDNSException(exceptions.Backend):
     pass
@@ -144,13 +136,13 @@ class EnhancedDNSClient(object):
         return zone
 
     def getZone(self, zoneName):
-        LOG.debug("Performing getZone with zoneName: %s" % zoneName)
+        LOG.debug("Performing getZone with zoneName: %s", zoneName)
         zoneName = self._sanitizeZoneName(zoneName)
 
         try:
             return self.client.service.getZone(zoneName=zoneName)
         except Exception as e:
-            raise EnhancedDNSException('Akamai Communication Failure: %s' % e)
+            raise EnhancedDNSException('Akamai Communication Failure: %s', e)
 
     def setZones(self, zones):
         LOG.debug("Performing setZones")
@@ -169,7 +161,7 @@ class EnhancedDNSClient(object):
                                            % e)
 
     def setZone(self, zone):
-        LOG.debug("Performing setZone with zoneName: %s" % zone.zoneName)
+        LOG.debug("Performing setZone with zoneName: %s", zone.zoneName)
         try:
             self.client.service.setZone(zone=zone)
         except Exception as e:
@@ -241,21 +233,7 @@ def build_zone(client, target, zone):
 class AkamaiBackend(base.Backend):
     __plugin_name__ = 'akamai'
 
-    __backend_status__ = 'release-compatible'
-
-    @classmethod
-    def get_cfg_opts(cls):
-        group = cfg.OptGroup(
-            name='backend:akamai', title='Backend options for Akamai'
-        )
-
-        opts = [
-            cfg.StrOpt('enhanceddns_wsdl',
-               default='file://%s' % WSDL,
-               help='Akamai EnhancedDNS WSDL URL'),
-        ]
-
-        return [(group, opts)]
+    __backend_status__ = 'untested'
 
     def __init__(self, target):
         super(AkamaiBackend, self).__init__(target)
