@@ -26,7 +26,7 @@ LOG = logging.getLogger(__name__)
 class InfobloxBackend(base.Backend):
     """Provides a Designate Backend for Infoblox"""
 
-    __backend_status__ = 'release-compatible'
+    __backend_status__ = 'untested'
 
     __plugin_name__ = 'infoblox'
 
@@ -44,7 +44,8 @@ class InfobloxBackend(base.Backend):
     def create_zone(self, context, zone):
         LOG.info('Create Zone %r', zone)
 
-        dns_net_view = self.infoblox.get_dns_view(context.tenant)
+        project_id = context.project_id or zone.tenant_id
+        dns_net_view = self.infoblox.get_dns_view(project_id)
         self.infoblox.create_zone_auth(
             fqdn=zone['name'][0:-1],
             dns_view=dns_net_view
