@@ -41,7 +41,6 @@ class NotifyEndpoint(base.BaseEndpoint):
     RPC_API_VERSION = '2.0'
     RPC_API_NAMESPACE = 'notify'
 
-    @metrics.timed('mdns.notify_zone_changed')
     def notify_zone_changed(self, context, zone, host, port, timeout,
                             retry_interval, max_retries, delay):
         """
@@ -61,34 +60,19 @@ class NotifyEndpoint(base.BaseEndpoint):
             current_retry is the current retry number.
             The return value is just used for testing and not by pool manager.
         """
-        time.sleep(delay)
-        return self._make_and_send_dns_message(
-            zone, host, port, timeout, retry_interval, max_retries,
-            notify=True)
+        start_time = time.time()
+        try:
+            time.sleep(delay)
+            return self._make_and_send_dns_message(
+                zone, host, port, timeout, retry_interval, max_retries,
+                notify=True)
+        finally:
+            metrics.timing('mdns.notify_zone_changed',
+                           time.time() - start_time)
 
     def poll_for_serial_number(self, context, zone, nameserver, timeout,
                                retry_interval, max_retries, delay):
-        """Get the serial number of a zone on a resolver, then call update_status
-        on Pool Manager to update the zone status.
-
-        :param context: The user context.
-        :param zone: The designate zone object.  This contains the zone
-            name. zone.serial = expected_serial
-        :param nameserver: Destination for the poll
-        :param timeout: The time (in seconds) to wait for a SOA response from
-            nameserver.
-        :param retry_interval: The time (in seconds) between retries.
-        :param max_retries: The maximum number of retries mindns would do for
-            an expected serial number. After this many retries, mindns returns
-            an ERROR.
-        :param delay: The time to wait before sending the first request.
-        :return: None
-        """
-        status, actual_serial, retries = self.get_serial_number(
-            context, zone, nameserver.host, nameserver.port, timeout,
-            retry_interval, max_retries, delay)
-        self.pool_manager_api.update_status(
-            context, zone, nameserver, status, actual_serial)
+        return
 
     def get_serial_number(self, context, zone, host, port, timeout,
                           retry_interval, max_retries, delay):
@@ -123,9 +107,10 @@ class NotifyEndpoint(base.BaseEndpoint):
             response, retry_cnt = self._make_and_send_dns_message(
                 zone, host, port, timeout, retry_interval, retries_left)
 
-            if response and (response.rcode() in (
-                    dns.rcode.NXDOMAIN, dns.rcode.REFUSED, dns.rcode.SERVFAIL)
-                    or not bool(response.answer)):
+            if response and (response.rcode() in (dns.rcode.NXDOMAIN,
+                                                  dns.rcode.REFUSED,
+                                                  dns.rcode.SERVFAIL) or
+                             not bool(response.answer)):
                 status = 'NO_ZONE'
                 if zone.serial == 0 and zone.action in ('DELETE', 'NONE'):
                     actual_serial = 0
@@ -247,21 +232,29 @@ class NotifyEndpoint(base.BaseEndpoint):
             # recover by retrying
             break
 
+        if not response:
+            return None, retry
+
         # Check that we actually got a NOERROR in the rcode and and an
         # authoritative answer
-        if response is None:
-            pass
-
-        elif (response.rcode() in
-                (dns.rcode.NXDOMAIN, dns.rcode.REFUSED,
-                    dns.rcode.SERVFAIL)) or \
+        refused_statuses = (
+            dns.rcode.NXDOMAIN, dns.rcode.REFUSED, dns.rcode.SERVFAIL
+        )
+        if (response.rcode() in refused_statuses or
                 (response.rcode() == dns.rcode.NOERROR and
-                    not bool(response.answer)):
-            LOG.info("%(zone)s not found on %(server)s:%(port)d",
-                     {'zone': zone.name, 'server': host, 'port': port})
-
-        elif not (response.flags & dns.flags.AA) or dns.rcode.from_flags(
-                response.flags, response.ednsflags) != dns.rcode.NOERROR:
+                 not bool(response.answer))):
+            if notify:
+                LOG.info(
+                    '%(zone)s not found on %(server)s:%(port)d',
+                    {
+                        'zone': zone.name,
+                        'server': host,
+                        'port': port
+                    }
+                )
+        elif (not (response.flags & dns.flags.AA) or
+                dns.rcode.from_flags(response.flags,
+                                     response.ednsflags) != dns.rcode.NOERROR):
             LOG.warning("Failed to get expected response while trying to "
                         "send '%(msg)s' for '%(zone)s' to '%(server)s:"
                         "%(port)d'.\nResponse message:\n%(resp)s\n",
