@@ -20,7 +20,8 @@ from designate import objects
 class NotSpecifiedSential:
     pass
 
-REQUIRED_RE = re.compile("\'([\w]*)\' is a required property")
+
+REQUIRED_RE = re.compile(r"\'([\w]*)\' is a required property")
 
 
 class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
@@ -90,8 +91,8 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
                 'fields', {}).items():
 
             # Check if this field as actually a nested object
-            if object.FIELDS.get(path_segment, {}).get('relation', False):
-
+            field = object.FIELDS.get(path_segment, {})
+            if isinstance(field, dict) and field.get('relation'):
                 obj_cls = object.FIELDS.get(path_segment).get('relation_cls')
                 obj_adapter = cls.get_object_adapter(
                     cls.ADAPTER_FORMAT,
@@ -104,6 +105,18 @@ class ValidationErrorAPIv2Adapter(base.APIv2Adapter):
 
                 # No need to continue the loop
                 break
+            elif hasattr(field, 'objname'):
+                obj_cls = field.objname
+                obj_adapter = cls.get_object_adapter(
+                    cls.ADAPTER_FORMAT, obj_cls)
+
+                object = objects.DesignateObject.obj_cls_from_name(obj_cls)()  # noqa
+                # Recurse down into this object
+                path_segment, obj_adapter = cls._rename_path_segment(
+                    obj_adapter, object, path_segment)
+
+                # No need to continue the loop
+                break
 
             if not isinstance(
                 value.get(
