@@ -13,27 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
+from designate.objects import fields
 
 
+@base.DesignateRegistry.register
 class Blacklist(base.DictObjectMixin, base.PersistentObjectMixin,
                 base.DesignateObject):
-    FIELDS = {
-        'pattern': {
-            'schema': {
-                'type': 'string',
-                'description': 'Regex for blacklisted zone name',
-                'format': 'regex',
-                'maxLength': 255,
-            },
-            'required': True
-        },
-        'description': {
-            'schema': {
-                'type': ['string', 'null'],
-                'description': 'Description for the blacklisted zone',
-                'maxLength': 160
-            }
-        }
+    fields = {
+        'pattern': fields.StringFields(maxLength=255),
+        'description': fields.StringFields(maxLength=160, nullable=True),
     }
 
     STRING_KEYS = [
@@ -41,5 +29,10 @@ class Blacklist(base.DictObjectMixin, base.PersistentObjectMixin,
     ]
 
 
+@base.DesignateRegistry.register
 class BlacklistList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = Blacklist
+
+    fields = {
+        'objects': fields.ListOfObjectsField('Blacklist'),
+    }
