@@ -17,7 +17,9 @@ fi
 # cleanup_designate - Remove residual data files, anything left over from previous
 # runs that a clean run would need to clean up
 function cleanup_designate {
-    sudo rm -rf $DESIGNATE_STATE_PATH $DESIGNATE_AUTH_CACHE_DIR
+    sudo rm -rf $DESIGNATE_STATE_PATH
+    sudo rm -f $(apache_site_config_for designate-api)
+    remove_uwsgi_config "$DESIGNATE_UWSGI_CONF" "$DESIGNATE_UWSGI"
     cleanup_designate_backend
 }
 
@@ -52,25 +54,34 @@ function configure_designate {
         iniset $DESIGNATE_CONF coordination backend_url $DESIGNATE_COORDINATION_URL
     fi
 
+    # Agent Configuration
+    iniset $DESIGNATE_CONF service:agent workers $API_WORKERS
+
     # API Configuration
     sudo cp $DESIGNATE_DIR/etc/designate/api-paste.ini $DESIGNATE_APIPASTE_CONF
     iniset $DESIGNATE_CONF service:api enabled_extensions_v2 $DESIGNATE_ENABLED_EXTENSIONS_V2
     iniset $DESIGNATE_CONF service:api enabled_extensions_admin $DESIGNATE_ENABLED_EXTENSIONS_ADMIN
-    iniset $DESIGNATE_CONF service:api api_base_uri $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/
+    iniset $DESIGNATE_CONF service:api enable_host_header True
     iniset $DESIGNATE_CONF service:api enable_api_v2 $DESIGNATE_ENABLE_API_V2
     iniset $DESIGNATE_CONF service:api enable_api_admin $DESIGNATE_ENABLE_API_ADMIN
 
+    # Central Configuration
+    iniset $DESIGNATE_CONF service:central workers $API_WORKERS
+
     # mDNS Configuration
     iniset $DESIGNATE_CONF service:mdns listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_MDNS}
+    iniset $DESIGNATE_CONF service:mdns workers $API_WORKERS
+
+    # Producer Configuration
+    iniset $DESIGNATE_CONF service:producer workers $API_WORKERS
+
+    # Sink Configuration
+    iniset $DESIGNATE_CONF service:sink workers $API_WORKERS
 
     # Worker Configuration
-    if is_service_enabled designate-worker; then
-        iniset $DESIGNATE_CONF service:worker notify True
-        iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
-        iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
-    else
-        iniset $DESIGNATE_CONF service:worker enabled False
-    fi
+    iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
+    iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
+    iniset $DESIGNATE_CONF service:worker workers $API_WORKERS
 
     # Set up Notifications/Ceilometer Integration
     iniset $DESIGNATE_CONF oslo_messaging_notifications driver "$DESIGNATE_NOTIFICATION_DRIVER"
@@ -91,35 +102,54 @@ function configure_designate {
     sudo chown root:root $tempfile
     sudo mv $tempfile /etc/sudoers.d/designate-rootwrap
 
-    # TLS Proxy Configuration
     if is_service_enabled tls-proxy; then
-        # Set the service port for a proxy to take the original
-        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_INT}
         iniset $DESIGNATE_CONF keystone cafile $SSL_BUNDLE_FILE
-    else
-        iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT}
     fi
 
     # Setup the Keystone Integration
     if is_service_enabled keystone; then
         iniset $DESIGNATE_CONF service:api auth_strategy keystone
-        configure_auth_token_middleware $DESIGNATE_CONF designate $DESIGNATE_AUTH_CACHE_DIR
+        configure_keystone_authtoken_middleware $DESIGNATE_CONF designate
         iniset $DESIGNATE_CONF keystone region_name $REGION_NAME
         iniset $DESIGNATE_CONF service:api quotas_verify_project_id True
     fi
 
     # Logging Configuration
-    if [ "$USE_SYSTEMD" != "False" ]; then
-        setup_systemd_logging $DESIGNATE_CONF
-    fi
-
-    # Format logging
-    if [ "$LOG_COLOR" == "True" ] && [ "$USE_SYSTEMD" == "False" ]; then
-        setup_colorized_logging $DESIGNATE_CONF DEFAULT
-    fi
+    setup_systemd_logging $DESIGNATE_CONF
 
     # Backend Plugin Configuation
     configure_designate_backend
+
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        write_uwsgi_config "$DESIGNATE_UWSGI_CONF" "$DESIGNATE_UWSGI" "/dns"
+    else
+        _config_designate_apache_wsgi
+    fi
+}
+
+function _config_designate_apache_wsgi {
+    local designate_api_apache_conf
+    local venv_path=""
+    local designate_bin_dir=""
+    designate_bin_dir=$(get_python_exec_prefix)
+    designate_api_apache_conf=$(apache_site_config_for designate-api)
+
+    if [[ ${USE_VENV} = True ]]; then
+        venv_path="python-path=${PROJECT_VENV["designate"]}/lib/$(python_version)/site-packages"
+        designate_bin_dir=${PROJECT_VENV["designate"]}/bin
+    fi
+
+    sudo cp $DESIGNATE_DIR/devstack/files/apache-designate-api.template $designate_api_apache_conf
+    sudo sed -e "
+        s|%APACHE_NAME%|$APACHE_NAME|g;
+        s|%DESIGNATE_BIN_DIR%|$designate_bin_dir|g;
+        s|%SSLENGINE%|$designate_ssl|g;
+        s|%SSLCERTFILE%|$designate_certfile|g;
+        s|%SSLKEYFILE%|$designate_keyfile|g;
+        s|%USER%|$STACK_USER|g;
+        s|%VIRTUALENV%|$venv_path|g;
+        s|%APIWORKERS%|$API_WORKERS|g;
+    " -i $designate_api_apache_conf
 }
 
 function configure_designatedashboard {
@@ -178,10 +208,13 @@ function create_designate_accounts {
     if is_service_enabled designate-api; then
         create_service_user "designate"
 
+        local designate_api_url="$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns"
+
         get_or_create_service "designate" "dns" "Designate DNS Service"
-        get_or_create_endpoint "dns" \
+        get_or_create_endpoint \
+            "dns" \
             "$REGION_NAME" \
-            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/"
+            "$designate_api_url"
     fi
 }
 
@@ -198,15 +231,6 @@ function create_designate_pool_configuration {
 
 # init_designate - Initialize etc.
 function init_designate {
-    # Create cache dir
-    sudo mkdir -p $DESIGNATE_AUTH_CACHE_DIR
-    sudo chown $STACK_USER $DESIGNATE_AUTH_CACHE_DIR
-    rm -f $DESIGNATE_AUTH_CACHE_DIR/*
-
-    # Some Designate Backends require mdns be bound to port 53, make that
-    # doable.
-    sudo setcap 'cap_net_bind_service=+ep' $(readlink -f /usr/bin/python)
-
     # (Re)create designate database
     recreate_database designate utf8
 
@@ -218,11 +242,15 @@ function init_designate {
 
 # install_designate - Collect source and prepare
 function install_designate {
-    if is_ubuntu; then
-        install_package libcap2-bin
-    elif is_fedora; then
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        install_apache_uwsgi
+    else
+        install_apache_wsgi
+    fi
+
+    if is_fedora; then
         # bind-utils package provides `dig`
-        install_package libcap bind-utils
+        install_package bind-utils
     fi
 
     git_clone $DESIGNATE_REPO $DESIGNATE_DIR $DESIGNATE_BRANCH
@@ -269,7 +297,6 @@ function start_designate {
     start_designate_backend
 
     run_process designate-central "$DESIGNATE_BIN_DIR/designate-central --config-file $DESIGNATE_CONF"
-    run_process designate-api "$DESIGNATE_BIN_DIR/designate-api --config-file $DESIGNATE_CONF"
     run_process designate-mdns "$DESIGNATE_BIN_DIR/designate-mdns --config-file $DESIGNATE_CONF"
     run_process designate-agent "$DESIGNATE_BIN_DIR/designate-agent --config-file $DESIGNATE_CONF"
     run_process designate-sink "$DESIGNATE_BIN_DIR/designate-sink --config-file $DESIGNATE_CONF"
@@ -277,20 +304,32 @@ function start_designate {
     run_process designate-worker "$DESIGNATE_BIN_DIR/designate-worker --config-file $DESIGNATE_CONF"
     run_process designate-producer "$DESIGNATE_BIN_DIR/designate-producer --config-file $DESIGNATE_CONF"
 
-    # Start proxies if enabled
-    if is_service_enabled designate-api && is_service_enabled tls-proxy; then
-        start_tls_proxy designate-api '*' $DESIGNATE_SERVICE_PORT $DESIGNATE_SERVICE_HOST $DESIGNATE_SERVICE_PORT_INT &
+
+
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        run_process "designate-api" "$DESIGNATE_BIN_DIR/uwsgi --procname-prefix designate-api --ini $DESIGNATE_UWSGI_CONF"
+    else
+        enable_apache_site designate-api
+        restart_apache_server
+        tail_log designate-api /var/log/$APACHE_NAME/designate-api.log
     fi
 
-    if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q -O- $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT; do sleep 1; done"; then
-        die $LINENO "Designate did not start"
+    echo "Waiting for designate-api to start..."
+    if ! wait_for_service $SERVICE_TIMEOUT $DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST/dns; then
+        die $LINENO "designate-api did not start"
     fi
 }
 
 # stop_designate - Stop running processes
 function stop_designate {
+    if [[ "$DESIGNATE_WSGI_MODE" == "uwsgi" ]]; then
+        stop_process "designate-api"
+    else
+        disable_apache_site designate-api
+        restart_apache_server
+    fi
+
     stop_process designate-central
-    stop_process designate-api
     stop_process designate-mdns
     stop_process designate-agent
     stop_process designate-sink
